Coverage report

|  |  | Statements |  | Branches |  | Total
--- | --- | --- | --- | --- | --- | --- | ---
File | function |  | coverage | statements | missing | excluded |  | coverage | branches | partial |  | coverage
privacyforms_pdf / __init__.py | (no function) |  | 100% | 3 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / cli.py | create_extractor |  | 100% | 4 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / cli.py | main |  | 100% | 1 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / cli.py | check |  | 100% | 8 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / cli.py | extract |  | 100% | 12 | 0 | 0 |  | 100% | 2 | 0 |  | 100%
privacyforms_pdf / cli.py | list_fields |  | 100% | 21 | 0 | 0 |  | 100% | 6 | 0 |  | 100%
privacyforms_pdf / cli.py | get_value |  | 100% | 10 | 0 | 0 |  | 100% | 2 | 0 |  | 100%
privacyforms_pdf / cli.py | info |  | 100% | 8 | 0 | 0 |  | 100% | 2 | 0 |  | 100%
privacyforms_pdf / cli.py | fill_form |  | 100% | 24 | 0 | 0 |  | 100% | 8 | 0 |  | 100%
privacyforms_pdf / cli.py | (no function) |  | 100% | 33 | 0 | 2 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFCPUExecutionError.__init__ |  | 100% | 3 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | FormValidationError.__init__ |  | 100% | 3 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | FormValidationError.__str__ |  | 100% | 3 | 0 | 0 |  | 100% | 2 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor.__init__ |  | 100% | 5 | 0 | 0 |  | 100% | 2 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor._find_pdfcpu |  | 100% | 2 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor._run_command |  | 100% | 11 | 0 | 0 |  | 100% | 2 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor._sanitize_stderr |  | 100% | 4 | 0 | 0 |  | 100% | 2 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor._temporary_json_path |  | 100% | 2 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor.check_pdfcpu |  | 100% | 5 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor.get_pdfcpu_version |  | 100% | 2 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor.has_form |  | 100% | 6 | 0 | 0 |  | 100% | 2 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor.extract |  | 100% | 11 | 0 | 0 |  | 100% | 4 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor.extract_to_json |  | 100% | 6 | 0 | 0 |  | 100% | 2 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor.list_fields |  | 100% | 2 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor.get_field_value |  | 100% | 5 | 0 | 0 |  | 75% | 4 | 1 |  | 89%
privacyforms_pdf / extractor.py | PDFFormExtractor.get_field_by_id |  | 100% | 5 | 0 | 0 |  | 75% | 4 | 1 |  | 89%
privacyforms_pdf / extractor.py | PDFFormExtractor.get_field_by_name |  | 100% | 5 | 0 | 0 |  | 75% | 4 | 1 |  | 89%
privacyforms_pdf / extractor.py | PDFFormExtractor.validate_form_data |  | 100% | 22 | 0 | 0 |  | 100% | 14 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor._convert_to_pdfcpu_format |  | 100% | 15 | 0 | 0 |  | 100% | 8 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor.fill_form |  | 100% | 19 | 0 | 0 |  | 100% | 10 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor.fill_form_from_json |  | 100% | 10 | 0 | 0 |  | 100% | 4 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor._validate_pdf_path |  | 100% | 4 | 0 | 0 |  | 100% | 4 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor._parse_form_data |  | 100% | 12 | 0 | 0 |  | 100% | 6 | 0 |  | 100%
privacyforms_pdf / extractor.py | (no function) |  | 100% | 61 | 0 | 2 |  | 100% | 0 | 0 |  | 100%
Total |  |  | 100% | 347 | 0 | 4 |  | 97% | 94 | 3 |  | 99%

No items found using the specified filter.